Module message

Module message 

Message system for the Vortix application.

All state mutations flow through this centralized Message enum, following the Elm Architecture (TEA) pattern. This enables:

  • Easy debugging (log all messages)
  • Predictable state changes
  • Testable update logic

Structs

ActionMenuItem
An item in the action menu, mapping a key to a message.

Enums

Message
All messages that can modify application state.
ScrollMove
Direction for scrolling movement
SelectionMove
All messages that can modify application state.

Functions

get_bulk_actions
Get bulk/global actions (triggered by ‘b’)
get_single_actions
Get specific actions for the focused item/panel (triggered by ‘x’)